# Pomodoro App
Pomodoro timer made with Python and Tkinter

```
$ pip3 install --user pomodoroapp
$ pomodoroapp
```

![Alt text](https://raw.githubusercontent.com/andrayantelo/pomodoroapp/master/screenshot.png)
